==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/SimpleMacvlanConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SimpleMacvlanConfigFluent<A extends SimpleMacvlanConfigFluent<A>> extends BaseFluent<A>{
  public SimpleMacvlanConfigFluent() {
  }
  
  public SimpleMacvlanConfigFluent(SimpleMacvlanConfig instance) {
    this.copyInstance(instance);
  }
  private IPAMConfigBuilder ipamConfig;
  private String master;
  private String mode;
  private Integer mtu;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SimpleMacvlanConfig instance) {
    instance = (instance != null ? instance : new SimpleMacvlanConfig());
  
    if (instance != null) {
        this.withIpamConfig(instance.getIpamConfig());
        this.withMaster(instance.getMaster());
        this.withMode(instance.getMode());
        this.withMtu(instance.getMtu());
        this.withIpamConfig(instance.getIpamConfig());
        this.withMaster(instance.getMaster());
        this.withMode(instance.getMode());
        this.withMtu(instance.getMtu());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public IPAMConfig buildIpamConfig() {
    return this.ipamConfig!=null ?this.ipamConfig.build():null;
  }
  
  public A withIpamConfig(IPAMConfig ipamConfig) {
    _visitables.get("ipamConfig").remove(this.ipamConfig);
    if (ipamConfig!=null){ this.ipamConfig= new IPAMConfigBuilder(ipamConfig); _visitables.get("ipamConfig").add(this.ipamConfig);} else { this.ipamConfig = null; _visitables.get("ipamConfig").remove(this.ipamConfig); } return (A) this;
  }
  
  public boolean hasIpamConfig() {
    return this.ipamConfig != null;
  }
  
  public IpamConfigNested<A> withNewIpamConfig() {
    return new IpamConfigNested(null);
  }
  
  public IpamConfigNested<A> withNewIpamConfigLike(IPAMConfig item) {
    return new IpamConfigNested(item);
  }
  
  public IpamConfigNested<A> editIpamConfig() {
    return withNewIpamConfigLike(java.util.Optional.ofNullable(buildIpamConfig()).orElse(null));
  }
  
  public IpamConfigNested<A> editOrNewIpamConfig() {
    return withNewIpamConfigLike(java.util.Optional.ofNullable(buildIpamConfig()).orElse(new IPAMConfigBuilder().build()));
  }
  
  public IpamConfigNested<A> editOrNewIpamConfigLike(IPAMConfig item) {
    return withNewIpamConfigLike(java.util.Optional.ofNullable(buildIpamConfig()).orElse(item));
  }
  
  public String getMaster() {
    return this.master;
  }
  
  public A withMaster(String master) {
    this.master=master; return (A) this;
  }
  
  public boolean hasMaster() {
    return this.master != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public Integer getMtu() {
    return this.mtu;
  }
  
  public A withMtu(Integer mtu) {
    this.mtu=mtu; return (A) this;
  }
  
  public boolean hasMtu() {
    return this.mtu != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SimpleMacvlanConfigFluent that = (SimpleMacvlanConfigFluent) o;
    if (!java.util.Objects.equals(ipamConfig, that.ipamConfig)) return false;
  
    if (!java.util.Objects.equals(master, that.master)) return false;
  
    if (!java.util.Objects.equals(mode, that.mode)) return false;
  
    if (!java.util.Objects.equals(mtu, that.mtu)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(ipamConfig,  master,  mode,  mtu,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ipamConfig != null) { sb.append("ipamConfig:"); sb.append(ipamConfig + ","); }
    if (master != null) { sb.append("master:"); sb.append(master + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (mtu != null) { sb.append("mtu:"); sb.append(mtu + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class IpamConfigNested<N> extends IPAMConfigFluent<IpamConfigNested<N>> implements Nested<N>{
    IpamConfigNested(IPAMConfig item) {
      this.builder = new IPAMConfigBuilder(this, item);
    }
    IPAMConfigBuilder builder;
    
    public N and() {
      return (N) SimpleMacvlanConfigFluent.this.withIpamConfig(builder.build());
    }
    
    public N endIpamConfig() {
      return and();
    }
    
  
  }

}

==> openshift-model-operator-6.9.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/SimpleMacvlanConfigFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SimpleMacvlanConfigFluent<A extends SimpleMacvlanConfigFluent<A>> extends BaseFluent<A>{
  public SimpleMacvlanConfigFluent() {
  }
  
  public SimpleMacvlanConfigFluent(SimpleMacvlanConfig instance) {
    this.copyInstance(instance);
  }
  private IPAMConfigBuilder ipamConfig;
  private String master;
  private String mode;
  private Integer mtu;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SimpleMacvlanConfig instance) {
    instance = (instance != null ? instance : new SimpleMacvlanConfig());
    if (instance != null) {
          this.withIpamConfig(instance.getIpamConfig());
          this.withMaster(instance.getMaster());
          this.withMode(instance.getMode());
          this.withMtu(instance.getMtu());
          this.withIpamConfig(instance.getIpamConfig());
          this.withMaster(instance.getMaster());
          this.withMode(instance.getMode());
          this.withMtu(instance.getMtu());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public IPAMConfig buildIpamConfig() {
    return this.ipamConfig != null ? this.ipamConfig.build() : null;
  }
  
  public A withIpamConfig(IPAMConfig ipamConfig) {
    this._visitables.remove(this.ipamConfig);
    if (ipamConfig != null) {
        this.ipamConfig = new IPAMConfigBuilder(ipamConfig);
        this._visitables.get("ipamConfig").add(this.ipamConfig);
    } else {
        this.ipamConfig = null;
        this._visitables.get("ipamConfig").remove(this.ipamConfig);
    }
    return (A) this;
  }
  
  public boolean hasIpamConfig() {
    return this.ipamConfig != null;
  }
  
  public IpamConfigNested<A> withNewIpamConfig() {
    return new IpamConfigNested(null);
  }
  
  public IpamConfigNested<A> withNewIpamConfigLike(IPAMConfig item) {
    return new IpamConfigNested(item);
  }
  
  public IpamConfigNested<A> editIpamConfig() {
    return withNewIpamConfigLike(java.util.Optional.ofNullable(buildIpamConfig()).orElse(null));
  }
  
  public IpamConfigNested<A> editOrNewIpamConfig() {
    return withNewIpamConfigLike(java.util.Optional.ofNullable(buildIpamConfig()).orElse(new IPAMConfigBuilder().build()));
  }
  
  public IpamConfigNested<A> editOrNewIpamConfigLike(IPAMConfig item) {
    return withNewIpamConfigLike(java.util.Optional.ofNullable(buildIpamConfig()).orElse(item));
  }
  
  public String getMaster() {
    return this.master;
  }
  
  public A withMaster(String master) {
    this.master = master;
    return (A) this;
  }
  
  public boolean hasMaster() {
    return this.master != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode = mode;
    return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public Integer getMtu() {
    return this.mtu;
  }
  
  public A withMtu(Integer mtu) {
    this.mtu = mtu;
    return (A) this;
  }
  
  public boolean hasMtu() {
    return this.mtu != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SimpleMacvlanConfigFluent that = (SimpleMacvlanConfigFluent) o;
    if (!java.util.Objects.equals(ipamConfig, that.ipamConfig)) return false;
    if (!java.util.Objects.equals(master, that.master)) return false;
    if (!java.util.Objects.equals(mode, that.mode)) return false;
    if (!java.util.Objects.equals(mtu, that.mtu)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(ipamConfig,  master,  mode,  mtu,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ipamConfig != null) { sb.append("ipamConfig:"); sb.append(ipamConfig + ","); }
    if (master != null) { sb.append("master:"); sb.append(master + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (mtu != null) { sb.append("mtu:"); sb.append(mtu + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class IpamConfigNested<N> extends IPAMConfigFluent<IpamConfigNested<N>> implements Nested<N>{
    IpamConfigNested(IPAMConfig item) {
      this.builder = new IPAMConfigBuilder(this, item);
    }
    IPAMConfigBuilder builder;
    
    public N and() {
      return (N) SimpleMacvlanConfigFluent.this.withIpamConfig(builder.build());
    }
    
    public N endIpamConfig() {
      return and();
    }
    
  
  }

}
